# arduino

everything Arduino.

- [schematics](./schematics.md)
- [parts](./parts.md)
- [body](./body.md)
- sample code: 🌈 [colormaps](../../arduino/colormaps/), 🚨 [police](../../arduino/police/)

|   |
| --- |
| [![image](https://github.com/kamangir/assets3/raw/main/arduino/IMG_0151.JPG?raw=true)](https://github.com/kamangir/assets3/raw/main/arduino/IMG_0151.JPG?raw=true) |
| [![image](https://github.com/kamangir/assets3/raw/main/arduino/serial-plotter.gif?raw=true)](https://github.com/kamangir/assets3/raw/main/arduino/serial-plotter.gif?raw=true) |
